@@ -23,11 +23,13 @@ from pathlib import Path
 from typing import List
 
 from pontos.github.api import FileStatus
+from pontos.github.api.helper import RepositoryType
 from pontos.github.cmds import (
     create_pull_request,
     file_status,
     labels,
     pull_request,
+    repos,
     update_pull_request,
 )
 
@@ -38,6 +40,10 @@ def from_env(name: str) -> str:
     return os.environ.get(name, name)
 
 
+def get_repository_type(rtype: str) -> RepositoryType:
+    return RepositoryType[rtype]
+
+
 def parse_args(
     args: List[str] = None,
 ) -> Namespace:
@@ -187,7 +193,7 @@ def parse_args(
         choices=FileStatus,
         default=[FileStatus.ADDED, FileStatus.MODIFIED],
         nargs="+",
-        help=("What file status should be returned" "Default: %(default)s"),
+        help="What file status should be returned. Default: %(default)s",
     )
 
     file_status_parser.add_argument(
@@ -244,4 +250,41 @@ def parse_args(
         ),
     )
 
-    return parser.parse_args(args)
+    # orga-repos
+    repos_parser = subparsers.add_parser("repos", aliases=["R"])
+
+    repos_parser.set_defaults(func=repos)
+
+    repos_parser.add_argument("orga", help="GitHub organization to use")
+
+    repos_parser.add_argument(
+        "-t",
+        "--token",
+        default="GITHUB_TOKEN",
+        type=from_env,
+        help=(
+            "GitHub Token to access the repository. "
+            "Default looks for environment variable 'GITHUB_TOKEN'"
+        ),
+    )
+
+    repos_parser.add_argument(
+        "--type",
+        choices=RepositoryType,
+        type=get_repository_type,
+        default=RepositoryType.PUBLIC,
+        help=(
+            "Define the type of repositories that should be covered. "
+            "Default: %(default)s"
+        ),
+    )
+
+    repos_parser.add_argument(
+        "-p",
+        "--path",
+        help="Define the Path to save the Repository Information JSON",
+    )
+
+    parsed_args = parser.parse_args(args)
+
+    return parsed_args
