@@ -15,17 +15,19 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
+import json
 import sys
 from argparse import Namespace
+from pathlib import Path
 
-import requests
+import httpx
 
 from pontos.github.api import GitHubRESTApi
 from pontos.terminal import Terminal
 
 
-def pull_request(_terminal: Terminal, args: Namespace):
-    args.pr_func(args)
+def pull_request(terminal: Terminal, args: Namespace):
+    args.pr_func(terminal, args)
 
 
 def create_pull_request(terminal: Terminal, args: Namespace):
@@ -58,7 +60,7 @@ def create_pull_request(terminal: Terminal, args: Namespace):
             title=args.title,
             body=args.body,
         )
-    except requests.exceptions.RequestException as e:
+    except httpx.HTTPError as e:
         terminal.error(str(e))
         sys.exit(1)
 
@@ -86,7 +88,7 @@ def update_pull_request(terminal: Terminal, args: Namespace):
             title=args.title,
             body=args.body,
         )
-    except requests.exceptions.RequestException as e:
+    except httpx.HTTPError as e:
         terminal.error(str(e))
         sys.exit(1)
 
@@ -123,7 +125,7 @@ def file_status(terminal: Terminal, args: Namespace):
             if args.output:
                 args.output.write("\n".join(files) + "\n")
 
-    except requests.exceptions.RequestException as e:
+    except httpx.HTTPError as e:
         terminal.error(str(e))
         sys.exit(1)
 
@@ -150,6 +152,32 @@ def labels(terminal: Terminal, args: Namespace):
 
         git.set_labels(repo=args.repo, issue=args.issue, labels=issue_labels)
 
-    except requests.exceptions.RequestException as e:
+    except httpx.HTTPError as e:
+        terminal.error(str(e))
+        sys.exit(1)
+
+
+def repos(terminal: Terminal, args: Namespace):
+    git = GitHubRESTApi(token=args.token)
+
+    try:
+        # check if Orga is existing
+        if not git.organisation_exists(orga=args.orga):
+            terminal.error(
+                f"PR {args.orga} is not existing or authorisation failed."
+            )
+            sys.exit(1)
+        terminal.ok(f"Organization {args.orga} exists.")
+        orga_json = git.get_repositories(
+            orga=args.orga, repository_type=args.type
+        )
+        if args.path:
+            repo_info = Path(args.path)
+            with open(repo_info, encoding="utf-8", mode="w") as fp:
+                json.dump(orga_json, fp, indent=2)
+        else:
+            terminal.print(orga_json)
+
+    except httpx.HTTPError as e:
         terminal.error(str(e))
         sys.exit(1)
