@@ -25,10 +25,8 @@ from argparse import ArgumentParser, FileType, Namespace
 from pathlib import Path
 from typing import Tuple
 
-import requests
-
-from pontos import changelog, version
-from pontos.terminal.terminal import ConsoleTerminal
+from pontos.terminal.null import NullTerminal
+from pontos.terminal.rich import RichTerminal
 
 from .prepare import prepare
 from .release import release
@@ -60,6 +58,7 @@ def parse_args(args) -> Tuple[str, str, Namespace]:
         description="valid subcommands",
         help="additional help",
         dest="command",
+        required=True,
     )
 
     prepare_parser = subparsers.add_parser("prepare")
@@ -219,24 +218,20 @@ def parse_args(args) -> Tuple[str, str, Namespace]:
         "--dry-run", action="store_true", help="Do not upload signed files."
     )
     parsed_args = parser.parse_args(args)
-    token = os.environ["GITHUB_TOKEN"] if not args else "TOKEN"
-    user = os.environ["GITHUB_USER"] if not args else "USER"
+    token = os.getenv("GITHUB_TOKEN") if not args else "TOKEN"
+    user = os.getenv("GITHUB_USER") if not args else "USER"
     return user, token, parsed_args
 
 
 def main(
-    _path: Path = Path,
-    _requests: requests = requests,
-    _version: version = version,
-    _changelog: changelog = changelog,
     leave: bool = True,
     args=None,
 ):
     username, token, parsed_args = parse_args(args)
-    term = ConsoleTerminal(
-        verbose=1 if not parsed_args.quiet else 0,
-        log_file=parsed_args.log_file,
-    )
+    if parsed_args.quiet:
+        term = NullTerminal()
+    else:
+        term = RichTerminal()
 
     term.bold_info(f"pontos-release => {parsed_args.func.__name__}")
 
@@ -245,12 +240,8 @@ def main(
             if not parsed_args.func(
                 term,
                 parsed_args,
-                path=_path,
                 username=username,
                 token=token,
-                changelog_module=_changelog,
-                requests_module=_requests,
-                version_module=_version,
             ):
                 return sys.exit(1) if leave else False
         except subprocess.CalledProcessError as e:
