@@ -21,7 +21,8 @@ import sys
 from argparse import Namespace
 from pathlib import Path
 
-from pontos import changelog, version
+from pontos import changelog
+from pontos.git import Git
 from pontos.helper import shell_cmd_runner
 from pontos.terminal import Terminal
 
@@ -29,7 +30,7 @@ from .helper import (
     calculate_calendar_version,
     commit_files,
     find_signing_key,
-    get_current_version,
+    get_last_release_version,
     get_next_patch_version,
     get_project_name,
     update_version,
@@ -41,10 +42,6 @@ RELEASE_TEXT_FILE = ".release.md"
 def prepare(
     terminal: Terminal,
     args: Namespace,
-    *,
-    path: Path,
-    version_module: version,
-    changelog_module: changelog,
     **_kwargs,
 ) -> bool:
     git_tag_prefix: str = args.git_tag_prefix
@@ -72,15 +69,14 @@ def prepare(
     terminal.info(f"Preparing the release {release_version}")
 
     # guardian
-    git_tags = shell_cmd_runner("git tag -l")
+    git = Git()
+    git_tags = git.list_tags()
     git_version = f"{git_tag_prefix}{release_version}"
-    if git_version.encode() in git_tags.stdout.splitlines():
+    if git_version in git_tags:
         terminal.error(f"git tag {git_version} is already taken.")
         sys.exit(1)
 
-    executed, filename = update_version(
-        terminal, release_version, version_module
-    )
+    executed, filename = update_version(terminal, release_version)
     if not executed:
         return False
 
@@ -88,17 +84,17 @@ def prepare(
 
     changelog_bool = True
     if args.conventional_commits:
-        current_version = get_current_version(terminal)
+        last_release_version = get_last_release_version()
         output = f"v{release_version}.md"
         cargs = Namespace(
-            current_version=current_version,
+            current_version=last_release_version,
             next_version=release_version,
             output=output,
             space=space,
             project=project,
             config=args.cc_config,
         )
-        changelog_builder = changelog_module.ChangelogBuilder(
+        changelog_builder = changelog.ChangelogBuilder(
             terminal=terminal,
             args=cargs,
         )
@@ -121,16 +117,16 @@ def prepare(
             "",
         )
     else:
-        change_log_path = path.cwd() / "CHANGELOG.md"
+        change_log_path = Path.cwd() / "CHANGELOG.md"
         if args.changelog:
-            tmp_path = path.cwd() / Path(args.changelog)
+            tmp_path = Path.cwd() / Path(args.changelog)
             if tmp_path.is_file():
                 change_log_path = tmp_path
             else:
                 terminal.warning(f"{tmp_path} is not a file.")
 
         # Try to get the unreleased section of the specific version
-        updated, changelog_text = changelog_module.update(
+        updated, changelog_text = changelog.update(
             change_log_path.read_text(encoding="utf-8"),
             release_version,
             git_tag_prefix=git_tag_prefix,
@@ -139,7 +135,7 @@ def prepare(
 
         if not updated:
             # Try to get unversioned unrelease section
-            updated, changelog_text = changelog_module.update(
+            updated, changelog_text = changelog.update(
                 change_log_path.read_text(encoding="utf-8"),
                 release_version,
                 git_tag_prefix=git_tag_prefix,
@@ -171,7 +167,7 @@ def prepare(
     else:
         shell_cmd_runner(f"git tag {git_version} -m '{commit_msg}'")
 
-    release_text = path(RELEASE_TEXT_FILE)
+    release_text = Path(RELEASE_TEXT_FILE)
     release_text.write_text(changelog_text, encoding="utf-8")
 
     terminal.warning(
