@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-# pontos/release/release.py
 # Copyright (C) 2020-2022 Greenbone Networks GmbH
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
@@ -18,18 +16,17 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
 
-import json
 from argparse import Namespace
 from pathlib import Path
 
-import requests
+import httpx
 
-from pontos import changelog, version
+from pontos import changelog
+from pontos.github.api import GitHubRESTApi
 from pontos.helper import shell_cmd_runner
 from pontos.terminal import Terminal
 
 from .helper import (
-    build_release_dict,
     commit_files,
     find_signing_key,
     get_current_version,
@@ -45,14 +42,16 @@ def release(
     terminal: Terminal,
     args: Namespace,
     *,
-    path: Path,
-    version_module: version,
-    username: str,
     token: str,
-    requests_module: requests,
-    changelog_module: changelog,
     **_kwargs,
 ) -> bool:
+    if not token:
+        terminal.error(
+            "Token is missing. The GitHub token is required to create a "
+            "release."
+        )
+        return False
+
     project: str = (
         args.project
         if args.project is not None
@@ -84,28 +83,25 @@ def release(
     shell_cmd_runner(f"git push --follow-tags {git_remote_name}")
 
     terminal.info(f"Creating release for v{release_version}")
-    changelog_text: str = path(RELEASE_TEXT_FILE).read_text(encoding="utf-8")
+    changelog_text: str = Path(RELEASE_TEXT_FILE).read_text(encoding="utf-8")
 
-    headers = {"Accept": "application/vnd.github.v3+json"}
+    github = GitHubRESTApi(token=token)
 
-    base_url = f"https://api.github.com/repos/{space}/{project}/releases"
     git_version = f"{git_tag_prefix}{release_version}"
-    response = requests_module.post(
-        base_url,
-        headers=headers,
-        auth=(username, token),
-        json=build_release_dict(
+    repo = f"{space}/{project}"
+
+    try:
+        github.create_release(
+            repo,
             git_version,
-            changelog_text,
             name=f"{project} {release_version}",
-        ),
-    )
-    if response.status_code != 201:
-        terminal.error(f"Wrong response status code: {response.status_code}")
-        terminal.error(json.dumps(response.text, indent=4, sort_keys=True))
+            body=changelog_text,
+        )
+    except httpx.HTTPError as e:
+        terminal.error(str(e))
         return False
 
-    path(RELEASE_TEXT_FILE).unlink()
+    Path(RELEASE_TEXT_FILE).unlink()
 
     commit_msg = (
         f"Automatic adjustments after release\n\n"
@@ -115,15 +111,15 @@ def release(
     # set to new version add skeleton
     changelog_bool = False
     if not args.conventional_commits:
-        change_log_path = path.cwd() / "CHANGELOG.md"
+        change_log_path = Path.cwd() / "CHANGELOG.md"
         if args.changelog:
-            tmp_path = path.cwd() / Path(args.changelog)
+            tmp_path = Path.cwd() / Path(args.changelog)
             if tmp_path.is_file():
                 change_log_path = tmp_path
             else:
                 terminal.warning(f"{tmp_path} is not a file.")
 
-        updated = changelog_module.add_skeleton(
+        updated = changelog.add_skeleton(
             markdown=change_log_path.read_text(encoding="utf-8"),
             new_version=release_version,
             project_name=project,
@@ -135,9 +131,7 @@ def release(
 
         commit_msg += f"* Add empty changelog after {release_version}"
 
-    executed, filename = update_version(
-        terminal, next_version, version_module, develop=True
-    )
+    executed, filename = update_version(terminal, next_version, develop=True)
     if not executed:
         return False
 
