@@ -24,8 +24,7 @@ from typing import Any, Callable, Generator
 
 import colorful as cf
 
-# from pontos.terminal.log_config import process_logger
-from pontos.terminal.logger import TerminalLogger
+from pontos.helper import DownloadProgressIterable
 
 TERMINAL_SIZE_FALLBACK = (80, 24)  # use a small standard size as fallback
 
@@ -161,15 +160,22 @@ class Terminal(ABC):
                      implementation.
         """
 
+    @abstractmethod
+    def download_progress(self, progress: DownloadProgressIterable) -> None:
+        """
+        Display a download progress
+        """
+
 
 class ConsoleTerminal(Terminal):
+    """
+    A simple Terminal using colorful internally for highlighting
+    """
+
+    # Keep arguments for backwards compatibility but ignore them
+    # pylint: disable=unused-argument
     def __init__(self, *, verbose: int = 1, log_file: Path = None):
         super().__init__()
-        if log_file:
-            self._logger = TerminalLogger(log_file=log_file)
-        else:
-            self._logger = None
-        self._verbose = verbose
 
     @staticmethod
     def get_width() -> int:
@@ -210,15 +216,11 @@ class ConsoleTerminal(Terminal):
                     usable_width=usable_width,
                     offset=offset,
                 )
-        if self._verbose > 0:
-            if new_line:
-                print(style(f"{color(status)} {output}"), **kwargs)
-            else:
-                kwargs.update({"end": "", "flush": True})
-                print(style(f"{color(status)} {output}"), **kwargs)
-
-        if self._logger:
-            self._logger.log(message=f"{status} {output}")
+        if new_line:
+            print(style(f"{color(status)} {output}"), **kwargs)
+        else:
+            kwargs.update({"end": "", "flush": True})
+            print(style(f"{color(status)} {output}"), **kwargs)
 
     def _format_message(
         self,
@@ -278,3 +280,21 @@ class ConsoleTerminal(Terminal):
             {"status": Signs.INFO, "color": cf.cyan, "style": cf.bold}
         )
         self._print_status(*messages, **kwargs)
+
+    def download_progress(self, progress: DownloadProgressIterable) -> None:
+        spinner = ["-", "\\", "|", "/"]
+        if progress.length:
+            for percent in progress:
+                done = int(50 * percent)
+                self.out(
+                    f"\r[{'=' * done}{' ' * (50-done)}]", end="", flush=True
+                )
+        else:
+            i = 0
+            for _ in progress:
+                i = i + 1
+                if i == 4:
+                    i = 0
+                self.out(f"\r[{spinner[i]}]", end="", flush=True)
+
+        self.out(f"\r[{Signs.OK}]{' ' * 50}", end="", flush=True)
