@@ -17,17 +17,20 @@
 
 import sys
 from pathlib import Path
+from typing import Tuple
 
 from .__version__ import __version__
 from .cmake import CMakeVersionCommand
 from .go import GoVersionCommand
+from .javascript import JavaScriptVersionCommand
 from .python import PythonVersionCommand
 
 
-def main(leave=True, args=None):
+def main(leave=True, args=None) -> Tuple[bool, str]:
     available_cmds = [
         ("CMakeLists.txt", CMakeVersionCommand),
         ("pyproject.toml", PythonVersionCommand),
+        ("package.json", JavaScriptVersionCommand),
         ("go.mod", GoVersionCommand),
     ]
     for file_name, cmd in available_cmds:
