@@ -16,6 +16,7 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 import unittest
+
 from pontos import changelog
 
 UNRELEASED = """
@@ -43,8 +44,8 @@ something, somehing
 - cool stuff 1
 - cool stuff 2
 """
-        _, cl = changelog.update(test_md, '', '')
-        self.assertEqual(cl, '')
+        _, cl = changelog.update(test_md, "", "")
+        self.assertEqual(cl, "")
 
     def test_find_unreleased_information_before_another_version(self):
         test_md = f"""
@@ -69,14 +70,14 @@ I don't recognize it anymore
 [Unreleased]: https://github.com/greenbone/pontos/compare/v1.0.0...main 
 """
 
-        _, result = changelog.update(test_md, '', '')
+        _, result = changelog.update(test_md, "", "")
         self.assertEqual(result.strip(), changed.strip())
 
 
 def test_find_unreleased_information_no_other_version(self):
     test_md = UNRELEASED
 
-    _, result = changelog.update(test_md, '', '')
+    _, result = changelog.update(test_md, "", "")
     self.assertEqual(result.strip(), UNRELEASED.strip())
 
 
@@ -93,5 +94,5 @@ something, somehing
 {UNRELEASED}
         """
 
-    _, result = changelog.update(test_md, '', '')
+    _, result = changelog.update(test_md, "", "")
     self.assertEqual(result.strip(), UNRELEASED.strip())
