@@ -24,7 +24,7 @@ from io import StringIO
 from pathlib import Path
 from unittest.mock import MagicMock, call, patch
 
-import requests
+import httpx
 
 from pontos import changelog, release
 from pontos.release.helper import version
@@ -40,17 +40,29 @@ class ReleaseTestCase(unittest.TestCase):
         )
 
     @patch("pontos.release.release.shell_cmd_runner")
-    def test_release_successfully(self, _shell_mock):
-        fake_path_class = MagicMock(spec=Path)
-        fake_requests = MagicMock(spec=requests)
-        fake_post = MagicMock(spec=requests.Response).return_value
+    @patch("pontos.release.release.Path", spec=Path)
+    @patch("pontos.github.api.api.httpx", spec=httpx)
+    @patch("pontos.github.api.release.httpx", spec=httpx)
+    @patch("pontos.release.helper.version", spec=version)
+    @patch("pontos.release.release.changelog", spec=changelog)
+    def test_release_successfully(
+        self,
+        _changelog_mock,
+        _version_mock,
+        _requests_mock,
+        _requests2_mock,
+        _path_mock,
+        _shell_mock,
+    ):
+        _version_mock.main.return_value = (True, "MyProject.conf")
+        _changelog_mock.update.return_value = ("updated", "changelog")
+
+        fake_post = MagicMock(spec=httpx.Response).return_value
         fake_post.status_code = 201
         fake_post.text = self.valid_gh_release_response
-        fake_requests.post.return_value = fake_post
-        fake_version = MagicMock(spec=version)
-        fake_version.main.return_value = (True, "MyProject.conf")
-        fake_changelog = MagicMock(spec=changelog)
-        fake_changelog.update.return_value = ("updated", "changelog")
+        _requests_mock.post.return_value = fake_post
+        _requests2_mock.post.return_value = fake_post
+
         args = [
             "release",
             "--release-version",
@@ -61,27 +73,35 @@ class ReleaseTestCase(unittest.TestCase):
 
         with redirect_stdout(StringIO()):
             released = release.main(
-                _path=fake_path_class,
-                _requests=fake_requests,
-                _version=fake_version,
-                _changelog=fake_changelog,
                 leave=False,
                 args=args,
             )
         self.assertTrue(released)
 
     @patch("pontos.release.release.shell_cmd_runner")
-    def test_release_conventional_commits_successfully(self, _shell_mock):
-        fake_path_class = MagicMock(spec=Path)
-        fake_requests = MagicMock(spec=requests)
-        fake_post = MagicMock(spec=requests.Response).return_value
+    @patch("pontos.release.release.Path", spec=Path)
+    @patch("pontos.github.api.api.httpx", spec=httpx)
+    @patch("pontos.github.api.release.httpx", spec=httpx)
+    @patch("pontos.release.helper.version", spec=version)
+    @patch("pontos.release.release.changelog", spec=changelog)
+    def test_release_conventional_commits_successfully(
+        self,
+        _changelog_mock,
+        _version_mock,
+        _requests_mock,
+        _requests2_mock,
+        _path_mock,
+        _shell_mock,
+    ):
+        _version_mock.main.return_value = (True, "MyProject.conf")
+        _changelog_mock.update.return_value = ("updated", "changelog")
+
+        fake_post = MagicMock(spec=httpx.Response).return_value
         fake_post.status_code = 201
         fake_post.text = self.valid_gh_release_response
-        fake_requests.post.return_value = fake_post
-        fake_version = MagicMock(spec=version)
-        fake_version.main.return_value = (True, "MyProject.conf")
-        fake_changelog = MagicMock(spec=changelog)
-        fake_changelog.update.return_value = ("updated", "changelog")
+        _requests_mock.post.return_value = fake_post
+        _requests2_mock.post.return_value = fake_post
+
         args = [
             "release",
             "-CC",
@@ -89,29 +109,41 @@ class ReleaseTestCase(unittest.TestCase):
 
         with redirect_stdout(StringIO()):
             released = release.main(
-                _path=fake_path_class,
-                _requests=fake_requests,
-                _version=fake_version,
-                _changelog=fake_changelog,
                 leave=False,
                 args=args,
             )
         self.assertTrue(released)
 
     @patch("pontos.release.release.shell_cmd_runner")
+    @patch("pontos.release.release.Path", spec=Path)
+    @patch("pontos.github.api.api.httpx", spec=httpx)
+    @patch("pontos.github.api.release.httpx", spec=httpx)
+    @patch("pontos.release.helper.version", spec=version)
+    @patch("pontos.release.release.changelog", spec=changelog)
     def test_not_release_successfully_when_github_create_release_fails(
-        self, _shell_mock
+        self,
+        _changelog_mock,
+        _version_mock,
+        _requests_mock,
+        _requests2_mock,
+        _path_mock,
+        _shell_mock,
     ):
-        fake_path_class = MagicMock(spec=Path)
-        fake_requests = MagicMock(spec=requests)
-        fake_post = MagicMock(spec=requests.Response).return_value
+
+        _version_mock.main.return_value = (True, "MyProject.conf")
+        _changelog_mock.update.return_value = ("updated", "changelog")
+
+        fake_post = MagicMock(spec=httpx.Response).return_value
         fake_post.status_code = 401
         fake_post.text = self.valid_gh_release_response
-        fake_requests.post.return_value = fake_post
-        fake_version = MagicMock(spec=version)
-        fake_version.main.return_value = (True, "MyProject.conf")
-        fake_changelog = MagicMock(spec=changelog)
-        fake_changelog.update.return_value = ("updated", "changelog")
+        fake_post.raise_for_status.side_effect = httpx.HTTPStatusError(
+            "Authorization required",
+            response=fake_post,
+            request=_requests_mock.post,
+        )
+        _requests_mock.post.return_value = fake_post
+        _requests2_mock.post.return_value = fake_post
+
         args = [
             "release",
             "--release-version",
@@ -120,27 +152,35 @@ class ReleaseTestCase(unittest.TestCase):
 
         with redirect_stdout(StringIO()):
             released = release.main(
-                _path=fake_path_class,
-                _requests=fake_requests,
-                _version=fake_version,
-                _changelog=fake_changelog,
                 leave=False,
                 args=args,
             )
         self.assertFalse(released)
 
     @patch("pontos.release.release.shell_cmd_runner")
-    def test_release_to_specific_git_remote(self, shell_mock):
-        fake_path_class = MagicMock(spec=Path)
-        fake_requests = MagicMock(spec=requests)
-        fake_post = MagicMock(spec=requests.Response).return_value
+    @patch("pontos.release.release.Path", spec=Path)
+    @patch("pontos.github.api.api.httpx", spec=httpx)
+    @patch("pontos.github.api.release.httpx", spec=httpx)
+    @patch("pontos.release.helper.version", spec=version)
+    @patch("pontos.release.release.changelog", spec=changelog)
+    def test_release_to_specific_git_remote(
+        self,
+        _changelog_mock,
+        _version_mock,
+        _requests_mock,
+        _requests2_mock,
+        _path_mock,
+        shell_mock,
+    ):
+        _version_mock.main.return_value = (True, "MyProject.conf")
+        _changelog_mock.update.return_value = ("updated", "changelog")
+
+        fake_post = MagicMock(spec=httpx.Response).return_value
         fake_post.status_code = 201
         fake_post.text = self.valid_gh_release_response
-        fake_requests.post.return_value = fake_post
-        fake_version = MagicMock(spec=version)
-        fake_version.main.return_value = (True, "MyProject.conf")
-        fake_changelog = MagicMock(spec=changelog)
-        fake_changelog.update.return_value = ("updated", "changelog")
+        _requests_mock.post.return_value = fake_post
+        _requests2_mock.post.return_value = fake_post
+
         args = [
             "release",
             "--project",
@@ -157,10 +197,6 @@ class ReleaseTestCase(unittest.TestCase):
 
         with redirect_stdout(StringIO()):
             released = release.main(
-                _path=fake_path_class,
-                _requests=fake_requests,
-                _version=fake_version,
-                _changelog=fake_changelog,
                 leave=False,
                 args=args,
             )
